==> qmmp_0.7.6.orig.tar.gz: qmmp-0.7.6/src/app/translations/qmmp_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>プレイリストをクリアしない</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Start playing current song</source>
        <translation>今の曲から再生を開始</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Pause current song</source>
        <translation>今の曲で一時停止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="66"/>
        <source>Pause if playing, play otherwise</source>
        <translation>再生中なら一時停止、一時停止しておれば再生</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="67"/>
        <source>Stop current song</source>
        <translation>今の曲で終止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="68"/>
        <source>Display Jump to File dialog</source>
        <translation>「ファイルを指定して即刻再生」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="69"/>
        <source>Quit application</source>
        <translation>アプリケーションを終了</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="70"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>音量設定 (例: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Skip forward in playlist</source>
        <translation>プレイリストでの次の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Skip backwards in playlist</source>
        <translation>プレイリストで前の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Show/hide application</source>
        <translation>アプリケーションウィンドウを表示/非表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Display Add File dialog</source>
        <translation>「ファイル追加」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Display Add Directory dialog</source>
        <translation>「ディレクトリ追加」ダイアログを表示</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="83"/>
        <source>Unknown command</source>
        <translation>不明なコマンドです</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="286"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>使用法: qmmp [オプション] [ファイル名:複数可]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="287"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="291"/>
        <source>Don&apos;t start the application</source>
        <translation>アプリケーションを始動しない</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="292"/>
        <source>Display this text and exit</source>
        <translation>このメッセージを表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="293"/>
        <source>Print version number and exit</source>
        <translation>バージョン番号を表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="294"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>名案, パッチ, バグ報告は forkotov02@hotmail.ru まで</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="299"/>
        <source>QMMP version: %1</source>
        <translation>QMMP のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="300"/>
        <source>Compiled with Qt version: %1</source>
        <translation>コンパイルに使用した Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="301"/>
        <source>Using Qt version: %1</source>
        <translation>現在使用中の Qt のバージョン: %1</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/app/translations/qmmp_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>プレイリストをクリアしない</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>今の曲から再生を開始</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>今の曲で一時停止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>再生中なら一時停止、一時停止しておれば再生</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>今の曲で終止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>「ファイルを指定して即刻再生」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>アプリケーションを終了</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>音量設定 (例: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation>消音/奏音</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>プレイリストでの次の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>プレイリストで前の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>アプリケーションウィンドウを表示/非表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation>メインウィンドウを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>「ファイル追加」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>「ディレクトリ追加」ダイアログを表示</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="88"/>
        <source>Unknown command</source>
        <translation>不明なコマンドです</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="315"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>使用法: qmmp [オプション] [ファイル名:複数可]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="316"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="320"/>
        <source>Don&apos;t start the application</source>
        <translation>アプリケーションを始動しない</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="321"/>
        <source>Display this text and exit</source>
        <translation>このメッセージを表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="322"/>
        <source>Print version number and exit</source>
        <translation>バージョン番号を表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="323"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>名案, パッチ, バグ報告は forkotov02@hotmail.ru まで</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="326"/>
        <source>Command Line Help</source>
        <translation>コマンド行ヘルプ</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="339"/>
        <source>QMMP version: %1</source>
        <translation>QMMP のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="340"/>
        <source>Compiled with Qt version: %1</source>
        <translation>コンパイルに使用した Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="341"/>
        <source>Using Qt version: %1</source>
        <translation>現在使用中の Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="344"/>
        <source>Qmmp Version</source>
        <translation>QMMP バージョン</translation>
    </message>
</context>
</TS>
